<?php
namespace Teknisa\Entities;

use Geral\Util\DateUtil;
use Setforms2\Shared\ORM\DateTime;
use Setforms2\Shared\Registry;
use Teknisa\Logic\SIT\Exception\ExceptionDePara;

class SitProdutoint extends Base\SitProdutoint
{


    public function insereProdutoDe($nrorgInt, $remessa, $cdProdutoInt, $nmProdutoInt, $unidInt, $pesoInt, $obs, $data, $operInt, $nrorg){
        try { 
            $this->setNrorgint((int)$nrorgInt);
            $this->setNrremessa((int)$remessa);
            $this->setCdprodutoint($cdProdutoInt);
            $this->setNmprodutoint($nmProdutoInt);
            $this->setCdunidadeint($unidInt);
            $this->setDsobsint(utf8_encode($obs));
            $this->setQtpesoint(floatval(str_replace(',', '.', $pesoInt)));

            // Linha comentada devido a formatacao do cliente que pode ser diferente.
            //$this->setDtrecebimento(DateUtil::getDataDeString($data, DateUtil::FORMATO_BRASILEIRO_DATAHORA));
            $this->setDtrecebimento(DateUtil::getDataAtual());

            $this->setIdativo('S');
            $this->setDtinclusao(DateUtil::getDataAtual());
            $this->setDtultatu(DateUtil::getDataAtual());
            $this->setNrorginclusao((int)$nrorg);
            $this->setCdoperinclusao($operInt);
            $this->setNrorg((int)$nrorg);
            
            $this->persist();
        } catch (\Exception $e) { 
            ExceptionDePara::erroInserirDe();
        }
    }


    public function atualizaProdutoDeErro(
        $nrorgInt, $remessa, $nmProdutoInt, $unidInt, $pesoInt, $obsInt, $dtRecebimento, $dtLiberacao, $dtEnvio, $operInt, $nrorg
    ){
        $this->setNrorgint((int)$nrorgInt);
        $this->setNrremessa((int)$remessa);
        $this->setNmprodutoint($nmProdutoInt);
        $this->setCdunidadeint($unidInt);
        $this->setQtpesoint(floatval(str_replace(',', '.', $pesoInt)));
        $this->setDtrecebimento(DateUtil::getDataDeString($dtRecebimento, DateUtil::FORMATO_BRASILEIRO_DATAHORA));
        $this->setDtliberacao($dtLiberacao);
        $this->setDtEnvio($dtEnvio);
        $this->setDsobsint($obsInt);

        $this->setIdativo('S');
        $this->setDtultatu(DateUtil::getDataAtual());
        $this->setNrorgultatu((int)$nrorg);
        $this->setCdoperultatu($operInt);
        $this->setNrorg((int)$nrorg);

        $this->persist();
    }


    public function atualizaProdutoDe($nrorgInt, $remessa, $nmProdutoInt, $unidInt, $pesoInt, $operInt, $nrorg){
        $this->setNrorgint((int)$nrorgInt);
        $this->setNrremessa((int)$remessa);
        $this->setNmprodutoint($nmProdutoInt);
        $this->setCdunidadeint($unidInt);
        $this->setQtpesoint(floatval(str_replace(',', '.', $pesoInt)));

        $this->setIdativo('S');
        $this->setDtultatu(DateUtil::getDataAtual());
        $this->setNrorgultatu((int)$nrorgInt);
        $this->setCdoperultatu($operInt);
        $this->setNrorg((int)$nrorg);

        $this->persist();
    }


    public function atualizaEnvio($nrorg){
        $this->setDtenvio(DateUtil::getDataAtual());
        $this->setDsobsint(null);

        $this->setDtultatu(DateUtil::getDataAtual(true));
        $this->setNrorgultatu((int)$nrorg);

        $this->persist();
    }
    
    
    public function atualizaProdutoPara(
        $produtoPara, $dtLiberacao, $nrorg, $operador, $peso
    ){
        $this->setCdproduto($produtoPara);
        $this->setDtLiberacao($dtLiberacao);
        $this->setQtpesoint($peso);

        $this->setDtultatu(DateUtil::getDataAtual());
        $this->setNrorgultatu((int)$nrorg);
        $this->setCdoperultatu($operador);
        $this->setNrorg((int)$nrorg);

        $this->persist();    	
    }


    public function atualizaEnvioPeloLog($nrorg) {
        $this->setDtenvio(null);

        $this->setDtultatu(DateUtil::getDataAtual());
        $this->setNrorgultatu((int)$nrorg);
        $this->setNrorg((int)$nrorg);

        $this->persist();
    }

    public static function excluiRegistro($registro) {
        $conn = Registry::getEntityManager();
        //
        try {
            $conn->beginTransaction();
            //
            if ($registro instanceof self) {
                $registro->setIdativo('N');
                $registro->setDtliberacao(DateUtil::getDataAtual());
                //
                $registro->persist();
            }
            $conn->flush();
            $conn->commit();
        } catch (\Exception $e) {
            $conn->rollback();
            throw $e;
        }
    }

    public function customUpdate(
        $idativo, $cdproduto, $qtpesoint, $dtultatu,
        $cdoperultatu, $nrorgultatu, $dtliberacao, $dtenvio
    ) {
        $this->setIdativo($idativo);
        $this->setCdproduto($cdproduto);
        $this->setQtpesoint($qtpesoint);
        //$this->setDtultatu($dtultatu);
        $this->setDtultatu(DateUtil::getDataAtual());
        $this->setCdoperultatu($cdoperultatu);
        $this->setNrorgultatu($nrorgultatu);
        $this->setDtliberacao($dtliberacao);
        $this->setDtenvio($dtenvio);
        //
        $this->persist();
    }

    /**
     * Verifica se o Produto já existe na tabela.
     *
     * @param String $nrorgint     Organização
     * @param String $cdprodutoint Código do Produto
     *
     * @return bool.
     */
    public static function produtoExistente ($nrorgint, $cdprodutoint)
    {
        $reg = self::getObjectByWhere(
            "NRORGINT = ? AND CDPRODUTOINT = ?",
            array($nrorgint, $cdprodutoint)
        );
        //
        if ($reg instanceof self) {
            return true;
        }
        //
        return false;
    }

    /**
     * Atualiza a Data de Envio do Registro que contém as PKs passadas por
     * parâmetro. Retorna o Número da Remessa em que esse registro foi enviado à
     * Teknisa.
     *
     * @param String $nrorg        Organização
     * @param String $nrorgint     Organização de Integração
     * @param String $cdprodutoint Código do Produto
     * @param String $dataAtual    Data Atual
     *
     * @return null.
     * @throws \Exception
     */
    public static function atualizaDtEnvio (
        $nrorg, $nrorgint, $cdprodutoint, $dataAtual
    ) {
        $reg = self::getObjectByWhere(
            "NRORG = ? AND NRORGINT = ? AND CDPRODUTOINT = ?",
            array($nrorg, $nrorgint, $cdprodutoint)
        );

        if ($reg instanceof self) {
            //Atualiza a Data de Envio
            $reg->setDtenvio($dataAtual);
            $reg->persist();
        }
    }
}